#
# spec file for package kf6-extra-cmake-modules
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor doc%{nil}
%if "%{flavor}" == "doc"
%global pkg_suffix -doc
%endif

%define rname extra-cmake-modules

# Full KF6 version (e.g. 6.3.0)
%{!?_kf6_version: %global _kf6_version %{version}}
# Last major and minor KF6 version (e.g. 6.0)
%{!?_kf6_bugfix_version: %define _kf6_bugfix_version %(echo %{_kf6_version} | awk -F. '{print $1"."$2}')}
%bcond_without doc
%bcond_without released
Name:           kf6-extra-cmake-modules%{?pkg_suffix}
Version:        6.3.0
Release:        1.1
Summary:        CMake modules
License:        BSD-3-Clause
URL:            https://www.kde.org
Source:         %{rname}-%{version}.tar.xz
%if %{with released}
Source1:        %{rname}-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
BuildRequires:  cmake >= 3.16
%if 0%{?suse_version} > 1500
BuildRequires:  gcc-c++
%else
BuildRequires:  gcc13-c++
BuildRequires:  gcc13-PIE
%endif
BuildRequires:  kf6-filesystem
%if "%{flavor}" != "doc"
Requires:       cmake >= 3.16
%if 0%{?suse_version} > 1500
Requires:       gcc-c++
%else
Requires:       gcc13-c++
Requires:       gcc13-PIE
%endif
# kf6-extra-cmake-modules is used to build both kf5 and kf6 based packages
# it has to require the resp. -filesystem package
Requires:       kf5-filesystem
Requires:       kf6-filesystem
Recommends:     kf6-extra-cmake-modules-doc
Provides:       extra-cmake-modules = %{version}
Obsoletes:      extra-cmake-modules < %{version}
%else
BuildRequires:  python3-Sphinx
Provides:       extra-cmake-modules-doc = %{version}
Obsoletes:      extra-cmake-modules-doc < %{version}
%endif
BuildArch:      noarch

%description
Extra modules and scripts for CMake.
%if "%{flavor}" == "doc"

This package provides documentation for kf6-extra-cmake-modules
%endif

%prep
%autosetup -p1 -n %{rname}-%{version}

%build
%cmake_kf6

%kf6_build

%install
%kf6_install

%if "%{flavor}" == "doc"
rm -r %{buildroot}%{_datadir}/ECM
%endif

%files
%if "%{flavor}" != "doc"
%license LICENSES/*
%{_datadir}/ECM/
%else
%doc %{_datadir}/doc/ECM/
%doc %lang(en) %{_mandir}/man7/ecm*.7*
%endif

%changelog
* Wed Jun  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.3.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.3.0/
- Changes since 6.2.0:
  * Skip app template packaging when cross-compiling
  * Remove explicit maintainer from metainfo
  * ECMQueryQt: Provide better error message when Qt6 qpaths is not found
* Mon May  6 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.2.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/6.2.0/
- Changes since 6.1.0:
  * API dox: KDEInstallDirs6: refer to qtpaths now as source of Qt paths
  * API dox: KDEInstallDirs6: drop outdated note about being in ALPHA state
  * test: Increase minimum cmake version so that it works with Qt 6.7
  * ECMQmlModule6: group qml and resource file calls
  * modules/ECMAddTests.cmake - handle unset or empty QT_PLUGIN_PATH
* Fri Apr  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.1.0
  * New feature release
- Changes since 6.0.0:
  * update version for new release
  * ECMAddQch: drop trying to set IMPORTED on targets with installed config
  * Fix DATAROOTDIR documentation for Windows
  * Update documentation favicon
  * macOS is the name of the Apple operating system
  * Fix fetch translations tests in GitLab forks
  * docs: Correct escape sequence for Python 3.12 or later
  * Map some more language codes to the IDs supported by Google Play
  * [ECMQmlModule] Add option to enable verbose compiler output
  * Remove extraneous docs-build CI job that is no longer needed following
    the switch of api.kde.org to Gitlab CI
  * Set ECM_PREFIX at build time rather than at runtime (kde#485158)
* Wed Feb 21 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.0
  * New bugfix release
  * Release announcement not available yet
- Changes since 5.249.0:
  * Filter out Asturian and Esperanto
  * Revert "Interlingua is now supported by Android"
  * update version for new release
* Wed Jan 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.249.0 (6.0 RC 2):
  * New bugfix release
  * For more details see https://kde.org/announcements/megarelease/6/rc2/
* Wed Jan 31 2024 Christophe Marin <christophe@krop.fr>
- Switch to the latest GCC version available in Leap for packages
  that can't build with the default compiler
* Mon Jan 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.248.0 (6.0 RC 1)
  * For more details please see:
    https://kde.org/announcements/megarelease/6/rc1/
* Mon Jan 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.248.0 (6.0 RC 1)
  * For more details please see:
  * https://kde.org/announcements/megarelease/6/rc1/
* Tue May 30 2023 Christophe Marin <christophe@krop.fr>
- Swith to gcc12 for Leap builds. Some frameworks fail to build
  with gcc10.
* Sat May 27 2023 Christophe Marin <christophe@krop.fr>
- Init kf6-extra-cmake-modules
